package com.ynet.life.file.parser;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.util.Region;

/* loaded from: com_ynet_life_file_parser.jar:com/ynet/life/file/parser/CommonDownloadXLSFileParser.class */
public class CommonDownloadXLSFileParser implements CommonDownloadFileParserInterface {
    @Override // com.ynet.life.file.parser.CommonDownloadFileParserInterface
    public byte[] writeToFile(List titles, List recordList, List outputFields, List outputFormats, List lastList, String filePathName, String encoding) throws TranFailException {
        HSSFWorkbook workBook = new HSSFWorkbook();
        HSSFSheet sheet = workBook.createSheet();
        HSSFRow row = sheet.createRow(0);
        if (titles != null) {
            short s = 0;
            while (true) {
                short i = s;
                if (i >= titles.size()) {
                    break;
                }
                String titleItem = (String) titles.get(i);
                createCell(row, i, titleItem);
                s = (short) (i + 1);
            }
        }
        int rowIndex = 1;
        Iterator iterator = recordList.iterator();
        while (iterator.hasNext()) {
            Map record = (Map) iterator.next();
            int i2 = rowIndex;
            rowIndex++;
            HSSFRow row2 = sheet.createRow(i2);
            short cellIndex = 0;
            for (int i3 = 0; i3 < outputFields.size(); i3++) {
                Object obj = record.get(outputFields.get(i3)) == null ? "" : record.get(outputFields.get(i3));
                String format = (String) outputFormats.get(i3);
                Trace.logInfo("传入下载字段格式：", format);
                String fieldValue = DownloadFileParserUtil.transformFormat(obj.toString(), format);
                Trace.logInfo("格式化后的字段值：", fieldValue);
                short s2 = cellIndex;
                cellIndex = (short) (s2 + 1);
                createCell(row2, s2, fieldValue);
            }
        }
        if (lastList.size() > 0) {
            StringBuffer contentString = new StringBuffer();
            for (int i4 = 0; i4 < lastList.size(); i4++) {
                Map filedMap = (Map) lastList.get(i4);
                for (Object key : filedMap.keySet()) {
                    String value = (String) filedMap.get(key);
                    contentString.append(key + ":" + value).append("     ");
                }
                HSSFRow row3 = sheet.createRow(recordList.size() + 1);
                createCell(row3, (short) 0, contentString.toString());
            }
            int startRow = recordList.size() + 1;
            int endRow = recordList.size() + 1;
            short endLine = (short) (titles.size() - 1);
            sheet.addMergedRegion(new Region(startRow, (short) 0, endRow, endLine));
        }
        FileOutputStream fileOut = null;
        try {
            try {
                fileOut = new FileOutputStream(filePathName);
                workBook.write(fileOut);
                byte[] b = workBook.getBytes();
                if (b.length > 0) {
                    try {
                        fileOut.close();
                        return b;
                    } catch (IOException ex) {
                        Trace.logError("LifeFile", "I/O异常", ex);
                        throw new TranFailException("EBLN0000", "I/O异常", ex);
                    }
                }
                try {
                    fileOut.close();
                    return null;
                } catch (IOException ex2) {
                    Trace.logError("LifeFile", "I/O异常", ex2);
                    throw new TranFailException("EBLN0000", "I/O异常", ex2);
                }
            } catch (IOException ex3) {
                Trace.logError("LifeFile", "文件写入失败", ex3);
                throw new TranFailException("EBLN0000", "文件写入失败", ex3);
            }
        } catch (Throwable th) {
            if (fileOut != null) {
                try {
                    fileOut.close();
                } catch (IOException ex4) {
                    Trace.logError("LifeFile", "I/O异常", ex4);
                    throw new TranFailException("EBLN0000", "I/O异常", ex4);
                }
            }
            throw th;
        }
    }

    private void createCell(HSSFRow row, short index, String content) {
        row.createCell(index).setCellValue(new HSSFRichTextString(content));
    }

    private void createCell(HSSFWorkbook wb, HSSFRow row, short index, String content, String fieldType) {
        HSSFCell cell = row.createCell(index);
        if ("amount".equalsIgnoreCase(fieldType)) {
            HSSFCellStyle cellStyle = wb.createCellStyle();
            cellStyle.setAlignment((short) 3);
            cell.setCellType(0);
            cell.setCellStyle(cellStyle);
            cell.setCellValue(new HSSFRichTextString(content));
            return;
        }
        cell.setCellValue(new HSSFRichTextString(content));
    }

    /* JADX WARN: Code restructure failed: missing block: B:27:0x01ce, code lost:
    
        if (r16 != null) goto L36;
     */
    /* JADX WARN: Code restructure failed: missing block: B:29:0x02fb, code lost:
    
        if (r0.hasNext() != false) goto L39;
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x028c, code lost:
    
        r0 = (java.util.Map) r0.next();
        r1 = r19;
        r19 = r19 + 1;
        r0 = r0.createRow(r1);
        r21 = 0;
        r24 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x02f1, code lost:
    
        if (r24 < r12.size()) goto L40;
     */
    /* JADX WARN: Code restructure failed: missing block: B:34:0x02bc, code lost:
    
        if (r0.get(r12.get(r24)) != null) goto L43;
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x02bf, code lost:
    
        r0 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:37:0x02d3, code lost:
    
        r11 = r0;
        r2 = r21;
        r21 = (short) (r2 + 1);
        createCell(r0, r2, r11.toString());
        r24 = r24 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:38:0x02c4, code lost:
    
        r0 = r0.get(r12.get(r24));
     */
    /* JADX WARN: Code restructure failed: missing block: B:42:0x02fe, code lost:
    
        r0 = r0.createRow(r19);
        r0 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:43:0x031c, code lost:
    
        r23 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:44:0x0326, code lost:
    
        if (r23 < (r10.size() - 1)) goto L50;
     */
    /* JADX WARN: Code restructure failed: missing block: B:45:0x030d, code lost:
    
        r0.createCell(r23);
        r0 = (short) (r23 + 1);
     */
    /* JADX WARN: Code restructure failed: missing block: B:47:0x0329, code lost:
    
        r0.addMergedRegion(new org.apache.poi.ss.util.Region(r19, 0, r19, (short) (r10.size() - 2)));
        r0 = r0.createFont();
        r0.setFontName("黑体");
        r0.setColor(8);
        r0.setItalic(true);
        r0.setFontHeight(250);
        r0 = r0.createCellStyle();
        r0.setAlignment(1);
        r0.setFont(r0);
        r0.getCell(0).setCellStyle(r0);
        r0.getCell(0).setCellValue(new org.apache.poi.hssf.usermodel.HSSFRichTextString("  *END OF REPORT*"));
        r21 = null;
     */
    /* JADX WARN: Code restructure failed: missing block: B:49:0x0399, code lost:
    
        r21 = new java.io.FileOutputStream(r14);
        r0.write(r21);
     */
    /* JADX WARN: Code restructure failed: missing block: B:51:0x03ef, code lost:
    
        r21.close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:52:0x03f4, code lost:
    
        return;
     */
    /* JADX WARN: Code restructure failed: missing block: B:55:0x03f5, code lost:
    
        r11 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:56:0x03f6, code lost:
    
        com.ynet.life.base.Trace.logError("LifeFile", "I/O异常", r11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:57:0x040a, code lost:
    
        throw new com.ynet.life.exception.TranFailException("EBLN0000", "I/O异常", r11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:59:0x03c7, code lost:
    
        r24 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:61:0x03cb, code lost:
    
        if (r21 != null) goto L74;
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x03ee, code lost:
    
        throw r24;
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x03ce, code lost:
    
        r21.close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:67:0x03d6, code lost:
    
        r11 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x03d7, code lost:
    
        com.ynet.life.base.Trace.logError("LifeFile", "I/O异常", r11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:69:0x03eb, code lost:
    
        throw new com.ynet.life.exception.TranFailException("EBLN0000", "I/O异常", r11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x03ae, code lost:
    
        r13 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:71:0x03b0, code lost:
    
        com.ynet.life.base.Trace.logError("LifeFile", "文件写入失败", r13);
     */
    /* JADX WARN: Code restructure failed: missing block: B:72:0x03c6, code lost:
    
        throw new com.ynet.life.exception.TranFailException("EBLN0000", "文件写入失败", r13);
     */
    /* JADX WARN: Code restructure failed: missing block: B:74:0x0286, code lost:
    
        if (r0.hasNext() != false) goto L25;
     */
    /* JADX WARN: Code restructure failed: missing block: B:75:0x01d4, code lost:
    
        r0 = (java.util.Map) r0.next();
        r1 = r19;
        r19 = r19 + 1;
        r0 = r0.createRow(r1);
        r21 = 0;
        r24 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:77:0x027c, code lost:
    
        if (r24 < r12.size()) goto L26;
     */
    /* JADX WARN: Code restructure failed: missing block: B:79:0x0204, code lost:
    
        if (r0.get(r12.get(r24)) != null) goto L29;
     */
    /* JADX WARN: Code restructure failed: missing block: B:80:0x0207, code lost:
    
        r0 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:81:0x021b, code lost:
    
        r11 = r0;
        r13 = "true";
        r0 = com.ynet.life.file.parser.DataFormatConfigProvider.getFieldAttrValue(r12.get(r24).toString(), "type", r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:82:0x023b, code lost:
    
        if ("amount".equalsIgnoreCase(r0) != false) goto L91;
     */
    /* JADX WARN: Code restructure failed: missing block: B:83:0x023e, code lost:
    
        r13 = com.ynet.life.file.parser.DataFormatConfigProvider.getFieldAttrValue(r12.get(r24).toString(), "opt", r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:85:0x0252, code lost:
    
        r0 = com.ynet.life.file.parser.FileParserUtil.transformFormat(r11.toString(), r0, r13);
        r3 = r21;
        r21 = (short) (r3 + 1);
        createCell(r0, r0, r3, r0, r0);
        r24 = r24 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:87:0x020c, code lost:
    
        r0 = r0.get(r12.get(r24));
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public void writeToFile(java.util.List r10, java.util.List r11, java.util.List r12, java.util.List r13, java.lang.String r14, java.lang.String r15, java.lang.String r16) throws com.ynet.life.exception.TranFailException {
        /*
            Method dump skipped, instructions count: 1035
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.ynet.life.file.parser.CommonDownloadXLSFileParser.writeToFile(java.util.List, java.util.List, java.util.List, java.util.List, java.lang.String, java.lang.String, java.lang.String):void");
    }
}
